@@ -462,6 +462,24 @@ def rescore():
     exporter.rescore_all()
 
 
+@click.command()
+@click.argument("member_id")
+def score_member(member_id):
+    """Score a member and write to console only"""
+    import exporter
+
+    exporter.score_member(member_id)
+
+
+@click.command()
+@click.argument("member_id")
+def member_position(member_id):
+    """Show how far into the members list a member is"""
+    import exporter
+
+    exporter.member_position(member_id=member_id)
+
+
 @click.command()
 @click.argument("doi")
 @click.option(
@@ -512,11 +530,13 @@ if __name__ == "__main__":
     cli.add_command(import_ocul)
     cli.add_command(import_pkp)
     cli.add_command(import_portico)
+    cli.add_command(member_position)
     cli.add_command(overall_report)
     cli.add_command(process_member)
     cli.add_command(process_members)
     cli.add_command(random_samples)
     cli.add_command(rescore)
+    cli.add_command(score_member)
     cli.add_command(show_archives)
     cli.add_command(show_cache)
     cli.add_command(show_issn)
