@@ -1,6 +1,7 @@
 import json
 import logging
 import os
+from collections import defaultdict, OrderedDict
 from datetime import date
 from datetime import timedelta
 from typing import DefaultDict, Any
@@ -138,25 +139,53 @@ def preservation_status(result) -> (dict, str):
     )
 
 
-def score(one_archive, two_archives, three_archives, sample_count):
+def score(
+    one_archive, two_archives, three_archives, sample_count, verbose=False
+):
+    score = "Unclassified"
+
     if sample_count > 0:
+        if verbose:
+            logging.info(
+                "Score for Bronze is: {}. Needs to be greater than 0.25".format(
+                    (one_archive / sample_count)
+                    + (two_archives / sample_count)
+                    + (three_archives / sample_count)
+                )
+            )
+
+            logging.info(
+                "Score for Silver is: {}. Needs to be greater than 0.50".format(
+                    (two_archives / sample_count)
+                    + (three_archives / sample_count)
+                )
+            )
+
+            logging.info(
+                "Score for Gold is: {}. Needs to be greater than 0.75".format(
+                    (three_archives / sample_count)
+                )
+            )
+
         # 25% in 1 or more archives
-        if (one_archive / sample_count) + (two_archives / sample_count) + (
-            three_archives / sample_count
+        if (
+            (one_archive / sample_count)
+            + (two_archives / sample_count)
+            + (three_archives / sample_count)
         ) >= 0.25:
-            return "Bronze"
+            score = "Bronze"
 
         # 50% in 2 or more archives
-        if (two_archives / sample_count) + (
-            three_archives / sample_count
+        if (
+            (two_archives / sample_count) + (three_archives / sample_count)
         ) >= 0.50:
-            return "Silver"
+            score = "Silver"
 
         # 75% in 3 archives
-        if three_archives / sample_count >= 0.75:
-            return "Gold"
+        if (three_archives / sample_count) >= 0.75:
+            score = "Gold"
 
-    return "Unclassified"
+    return score
 
 
 def process_member_sample(samples, sample_path, verbose=False) -> dict:
@@ -308,6 +337,20 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
     return overall_status
 
 
+def score_member(member_id):
+    return rescore_member(
+        ANNOTATION_BUCKET,
+        ANNOTATION_FILENAME,
+        ANNOTATION_PATH,
+        SAMPLES_BUCKET,
+        SAMPLES_PATH,
+        member_id,
+        CODE_BUCKET,
+        push_to_s3=False,
+        verbose=True,
+    )
+
+
 def push_json_to_s3(
     s3,
     json_obj,
@@ -443,6 +486,7 @@ def rescore_member(
     member_id,
     code_bucket,
     verbose=False,
+    push_to_s3=True,
 ):
     import boto3
     import logging
@@ -476,6 +520,7 @@ def rescore_member(
             two_archives,
             three_archives,
             preservations["sample-count"],
+            verbose=verbose,
         )
 
         key = f"{annotation_path}/members/{member_id}/{annotation_filename}"
@@ -484,12 +529,15 @@ def rescore_member(
             f"Rescoring member {member_id} as {preservations['member-grade']}"
         )
 
-        push_json_to_s3(
-            s3=s3,
-            json_obj=preservations,
-            bucket=annotation_bucket,
-            path=key,
-        )
+        if push_to_s3:
+            push_json_to_s3(
+                s3=s3,
+                json_obj=preservations,
+                bucket=annotation_bucket,
+                path=key,
+            )
+
+        return preservations["member-grade"]
     except Exception as e:
         logging.error(f"Unable to rescore member {member_id}. Error follows.")
         raise e
@@ -545,11 +593,60 @@ def overall_report(members=None, limit=0):
         ">USD 500 million": 50000,
     }
 
+    size_bracket_names = [
+        "Unknown",
+        "1-10",
+        "11-100",
+        "101-500",
+        "501-1,000",
+        "1,001-10,000",
+        "10,001-100,000",
+        "100,001-1,000,000",
+        "1,000,001+",
+    ]
+
+    size_brackets = OrderedDict(
+        {
+            0: 0,
+            1: 10,
+            11: 100,
+            101: 500,
+            501: 1000,
+            1001: 10000,
+            10001: 100000,
+            100001: 1000000,
+            1000001: -1,
+        }
+    )
+
     gold_members = {member_tier: 0 for member_tier in member_tier_names}
     silver_members = {member_tier: 0 for member_tier in member_tier_names}
     bronze_members = {member_tier: 0 for member_tier in member_tier_names}
     unclassified_members = {member_tier: 0 for member_tier in member_tier_names}
 
+    gold_members_by_country = defaultdict(int)
+    silver_members_by_country = defaultdict(int)
+    bronze_members_by_country = defaultdict(int)
+    unclassified_members_by_country = defaultdict(int)
+
+    gold_members_by_size = {
+        size_bracket: 0 for size_bracket in size_bracket_names
+    }
+    silver_members_by_size = {
+        size_bracket: 0 for size_bracket in size_bracket_names
+    }
+    bronze_members_by_size = {
+        size_bracket: 0 for size_bracket in size_bracket_names
+    }
+    unclassified_members_by_size = {
+        size_bracket: 0 for size_bracket in size_bracket_names
+    }
+
+    total_items_unpreserved = 0
+    total_items_preserved = 0
+    total_preservation_instances = 0
+    total_items_sampled = 0
+
     for member in members:
         logging.info(f"Fetching preservation statistics for member {member}")
 
@@ -601,22 +698,69 @@ def overall_report(members=None, limit=0):
         if not member_band:
             logging.warning(f"Unable to classify this member ({member})")
 
+        # now log the country here
+        country = member_obj["location"].split(",")[-1]
+
+        # size em up
+        deposits = member_obj["counts"]["total-dois"]
+
+        size = None
+
+        for key, val in size_brackets.items():
+            if deposits == 0:
+                size = "Unknown"
+            elif val == -1:
+                # special case
+                if deposits >= key:
+                    size = size_bracket_names[
+                        list(size_brackets.keys()).index(key)
+                    ]
+            elif key <= deposits <= val:
+                size = size_bracket_names[list(size_brackets.keys()).index(key)]
+
+        total_items_preserved += (
+            preservations["preserved-count"]
+            if "preserved-count" in preservations
+            else 0
+        )
+        total_items_unpreserved += (
+            preservations["unpreserved-count"]
+            if "unpreserved-count" in preservations
+            else 0
+        )
+        total_preservation_instances += (
+            preservations["preservation-instances"]
+            if "preservation-instances" in preservations
+            else 0
+        )
+        total_items_sampled += (
+            preservations["sample-count"]
+            if "sample-count" in preservations
+            else 0
+        )
+
         # this calculates the preservation grades for different member tiers
         # using fee level as the benchmark
         if preservations["member-grade"] == "Bronze":
             logging.info(f"{member_obj['primary-name']} is Bronze")
             bronze_members[member_band] += 1
+            bronze_members_by_country[country] += 1
+            bronze_members_by_size[size] += 1
         elif preservations["member-grade"] == "Silver":
             logging.info(f"{member_obj['primary-name']} is Silver")
             silver_members[member_band] += 1
+            silver_members_by_country[country] += 1
+            silver_members_by_size[size] += 1
         elif preservations["member-grade"] == "Gold":
             logging.info(f"{member_obj['primary-name']} is Gold")
             gold_members[member_band] += 1
+            gold_members_by_country[country] += 1
+            gold_members_by_size[size] += 1
         else:
             logging.info(f"{member_obj['primary-name']} is Unclassified")
             unclassified_members[member_band] += 1
-
-        pass
+            unclassified_members_by_country[country] += 1
+            unclassified_members_by_size[size] += 1
 
     gold_totals = sum(gold_members.values())
     silver_totals = sum(silver_members.values())
@@ -625,14 +769,26 @@ def overall_report(members=None, limit=0):
 
     # bundle this all up
     overall_result = {
-        "gold-members": gold_members,
-        "silver-members": silver_members,
-        "bronze-members": bronze_members,
-        "unclassified-members": unclassified_members,
+        "gold-members-by-fee": gold_members,
+        "silver-members-by-fee": silver_members,
+        "bronze-members-by-fee": bronze_members,
+        "unclassified-members-by-fee": unclassified_members,
         "gold-totals": gold_totals,
         "silver-totals": silver_totals,
         "bronze-totals": bronze_totals,
         "unclassified-totals": unclassified_totals,
+        "gold-members-by-country": gold_members_by_country,
+        "silver-members-by-country": silver_members_by_country,
+        "bronze-members-by-country": bronze_members_by_country,
+        "unclassified-members-by-country": unclassified_members_by_country,
+        "gold-members-by-size": gold_members_by_size,
+        "silver-members-by-size": silver_members_by_size,
+        "bronze-members-by-size": bronze_members_by_size,
+        "unclassified-members-by-size": unclassified_members_by_size,
+        "total-items-preserved": total_items_preserved,
+        "total-items-unpreserved": total_items_unpreserved,
+        "total-preservation-instances": total_preservation_instances,
+        "total-items-sampled": total_items_sampled,
     }
 
     key = f"{REPORT_PATH}/{REPORT_FILENAME}"
@@ -647,9 +803,31 @@ def overall_report(members=None, limit=0):
     return overall_result
 
 
+def member_position(members=None, limit=0, member_id=None):
+    import boto3
+    import logging
+
+    s3client = boto3.client("s3")
+    session = boto3.Session()
+    s3 = session.resource("s3")
+
+    if not members:
+        # get member list from S3
+        members = get_members(
+            s3client=s3client,
+            samples_bucket=SAMPLES_BUCKET,
+            samples_path=SAMPLES_PATH,
+        )
+
+    logging.info(
+        f"Member {member_id} is at position {members.index(member_id)} of {len(members)} ({members.index(member_id) / len(members) * 100}%)"
+    )
+
+
 def rescore_all(members=None, limit=0):
     import boto3
     import logging
+    from rich.progress import track
 
     s3client = boto3.client("s3")
     session = boto3.Session()
@@ -668,19 +846,18 @@ def rescore_all(members=None, limit=0):
 
     from joblib import Parallel, delayed
 
-    for member in members:
-        results = Parallel(n_jobs=PARALLEL_JOBS)(
-            delayed(rescore_member)(
-                ANNOTATION_BUCKET,
-                ANNOTATION_FILENAME,
-                ANNOTATION_PATH,
-                SAMPLES_BUCKET,
-                SAMPLES_PATH,
-                member_id,
-                CODE_BUCKET,
-            )
-            for member_id in members
+    results = Parallel(n_jobs=PARALLEL_JOBS)(
+        delayed(rescore_member)(
+            ANNOTATION_BUCKET,
+            ANNOTATION_FILENAME,
+            ANNOTATION_PATH,
+            SAMPLES_BUCKET,
+            SAMPLES_PATH,
+            member_id,
+            CODE_BUCKET,
         )
+        for member_id in track(members)
+    )
 
 
 def get_annotation(
